@@ -35,11 +35,24 @@ has screenCfg => sub {
     my $self = shift;
     return {
         type => 'form',
+        options => $self->screenOpts,
         form => $self->formCfg,
         action => $self->actionCfg,
     }
 };
 
+=head2 screenOpts
+
+Returns a hash of options for the screen Options
+
+=cut
+
+has screenOpts => sub {
+    {
+        warnAboutUnsavedData => 1
+    }
+};
+
 =head2 actionCfg
 
 Returns a list of action buttons to place at the top of the form.
