@@ -179,7 +179,9 @@ qx.Class.define("callbackery.ui.plugin.Action", {
                                     popup.dispose();
                                     this.fireEvent('popupClosed');
                                 },this,100);
-                                this.fireDataEvent('actionResponse',{action: 'reload'});
+                                if (!btnCfg.option && !btnCfg.option.noReload){
+                                    this.fireDataEvent('actionResponse',{action: 'reload'});
+                                }
                             },this);
                             popup.open();
                             break;
